@@ -28,9 +28,10 @@ class Group(ABC):
     Attributes:
         id (GroupID): the identification of the group.
         group_name (str): a human-readable name of the group.
-        number_to_observe (int): the number of children in the group that must be observed for the group to be considered complete.
+        number_to_observe (int): the number of children in the group that must be observed for the group to be
+                                 considered complete.
         delay_min(timedelta): used in cadences.
-        delay_ma(timedelta): used in cadences.
+        delay_max(timedelta): used in cadences.
         children (Union[List['Group'], Observation]): member(s) of the group
     """
     id: GroupID
@@ -46,7 +47,7 @@ class Group(ABC):
             raise ValueError(msg)
 
     def subgroup_ids(self) -> FrozenSet[GroupID]:
-        """Get the ids for all the sub-groups inside.
+        """Get the ids for all the subgroups inside.
 
         Returns:
             FrozenSet[GroupID]: Set of GroupID values.
@@ -121,7 +122,7 @@ class Group(ABC):
         if issubclass(type(self.children), Observation):
             return self.children.exec_time()
         else:
-            sum(child.exec_time() for child in self.children)
+            sum((child.exec_time() for child in self.children), timedelta())
 
     def program_used(self) -> timedelta:
         """Program time used across the group.
@@ -132,7 +133,7 @@ class Group(ABC):
         if issubclass(type(self.children), Observation):
             return self.children.program_used()
         else:
-            return sum(child.program_used() for child in self.children)
+            return sum((child.program_used() for child in self.children), timedelta())
 
     def partner_used(self) -> timedelta:
         """Partner time used across the group.
@@ -143,7 +144,7 @@ class Group(ABC):
         if issubclass(type(self.children), Observation):
             return self.children.partner_used()
         else:
-            return sum(child.partner_used() for child in self.children)
+            return sum((child.partner_used() for child in self.children), timedelta())
 
     def total_used(self) -> timedelta:
         """Total time used across the group: includes program time and partner time.
@@ -154,7 +155,7 @@ class Group(ABC):
         if issubclass(type(self.children), Observation):
             return self.children.total_used()
         else:
-            return sum(child.total_used() for child in self.children)
+            return sum((child.total_used() for child in self.children), timedelta())
 
     def show(self, depth: int = 1) -> NoReturn:
         """Print content of the Group.
